diff --git a/Source/AutoHDR.Displays/DisplayManagerNvidia.cs b/Source/AutoHDR.Displays/DisplayManagerNvidia.cs
index e7fb8ea..121ec46 100644
--- a/Source/AutoHDR.Displays/DisplayManagerNvidia.cs
+++ b/Source/AutoHDR.Displays/DisplayManagerNvidia.cs
@@ -105,7 +105,7 @@ public override void SetColorDepth(Display display, ColorDepth colorDepth)
{
DisplayDevice nvidiaDisplay = new DisplayDevice((uint)display.Tag);
NvAPIWrapper.Native.Display.ColorDataDepth nvColorDepth = colorDepth.ConvertNvidiaColorDepth();
- ColorData colorData = new ColorData(nvidiaDisplay.CurrentColorData.ColorFormat, nvidiaDisplay.CurrentColorData.Colorimetry, nvidiaDisplay.CurrentColorData.DynamicRange, NvAPIWrapper.Native.Display.ColorDataDepth.BPC8, nvidiaDisplay.CurrentColorData.SelectionPolicy, nvidiaDisplay.CurrentColorData.DesktopColorDepth);
+ ColorData colorData = new ColorData(nvidiaDisplay.CurrentColorData.ColorFormat, nvidiaDisplay.CurrentColorData.Colorimetry, nvidiaDisplay.CurrentColorData.DynamicRange, nvColorDepth, nvidiaDisplay.CurrentColorData.SelectionPolicy, nvidiaDisplay.CurrentColorData.DesktopColorDepth);
nvidiaDisplay.SetColorData(colorData);
}
diff --git a/Source/AutoHDR.ProjectResources/ProjectLocales.de.resx b/Source/AutoHDR.ProjectResources/ProjectLocales.de.resx
index d343009..96aa8ce 100644
--- a/Source/AutoHDR.ProjectResources/ProjectLocales.de.resx
+++ b/Source/AutoHDR.ProjectResources/ProjectLocales.de.resx
@@ -276,8 +276,8 @@
Hauptmonitor
-
- Letzte Aktion
+
+ Letzte Aktionen
Starte Anwendung
diff --git a/Source/AutoHDR.ProjectResources/ProjectLocales.resx b/Source/AutoHDR.ProjectResources/ProjectLocales.resx
index bea65c2..a7f734a 100644
--- a/Source/AutoHDR.ProjectResources/ProjectLocales.resx
+++ b/Source/AutoHDR.ProjectResources/ProjectLocales.resx
@@ -310,8 +310,8 @@
Primary
-
- Last action
+
+ Last actions
Launch application
diff --git a/Source/AutoHDR/App.xaml b/Source/AutoHDR/App.xaml
index d705f0c..dad9762 100644
--- a/Source/AutoHDR/App.xaml
+++ b/Source/AutoHDR/App.xaml
@@ -14,51 +14,18 @@
StartupUri="Views\AutoHDRMainView.xaml">
- https://paypal.me/HeikoH89
+
+
+
+
+
+
+
+ https://paypal.me/HeikoH89
https://github.com/Codectory/AutoHDR
- #2ac987
- #ff6666
- #fa8e8e
- #e36b6b
-
- White
- #fca9a9
- #FFDDDDDD
- White
- #FFCCCCCC
- #FF444444
- #cfcfcf
- #8a8a8a
-
- #FF888888
-
-
-
- 15
-
-
-
-
-
-
-
-
-
-
-
- #ad7b7b
- #757575
- #969696
- #a1a1a1
-
- #c6cbcf
-
-
- 5
- 5
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
\ No newline at end of file
diff --git a/Source/AutoHDR/Controls/DefaultBorder.xaml b/Source/AutoHDR/Controls/DefaultBorder.xaml
new file mode 100644
index 0000000..9c3fa38
--- /dev/null
+++ b/Source/AutoHDR/Controls/DefaultBorder.xaml
@@ -0,0 +1,24 @@
+
+
+
+
\ No newline at end of file
diff --git a/Source/AutoHDR/ProcessWatcher.cs b/Source/AutoHDR/ProcessWatcher.cs
index 69c21e5..1de0ce8 100644
--- a/Source/AutoHDR/ProcessWatcher.cs
+++ b/Source/AutoHDR/ProcessWatcher.cs
@@ -197,6 +197,8 @@ private void UpdateApplications()
private bool IsFocusedApplication(Process process)
{
Process currentProcess = GetForegroundProcess();
+ if (currentProcess == null)
+ return false;
return process.Id.Equals(currentProcess.Id);
}
diff --git a/Source/AutoHDR/Profiles/Actions/DisplayAction.cs b/Source/AutoHDR/Profiles/Actions/DisplayAction.cs
index abb35c5..c196cad 100644
--- a/Source/AutoHDR/Profiles/Actions/DisplayAction.cs
+++ b/Source/AutoHDR/Profiles/Actions/DisplayAction.cs
@@ -104,6 +104,8 @@ public override string ActionDescription
returnValue += $" {ProjectLocales.Resolution} {Resolution.Width}x{Resolution.Height}";
if (SetRefreshRate)
returnValue += $" {ProjectLocales.RefreshRate} {RefreshRate}Hz";
+ if (SetColorDepth)
+ returnValue += $" {ProjectLocales.ColorDepth} {ColorDepth}";
return returnValue;
}
}
diff --git a/Source/AutoHDR/Properties/AssemblyInfo.cs b/Source/AutoHDR/Properties/AssemblyInfo.cs
index c0b38c5..1a23215 100644
--- a/Source/AutoHDR/Properties/AssemblyInfo.cs
+++ b/Source/AutoHDR/Properties/AssemblyInfo.cs
@@ -52,5 +52,5 @@
// Sie können alle Werte angeben oder Standardwerte für die Build- und Revisionsnummern verwenden,
// indem Sie "*" wie unten gezeigt eingeben:
// [assembly: AssemblyVersion("1.0.*")]
-[assembly: AssemblyVersion("1.7.22.0")]
-[assembly: AssemblyFileVersion("1.7.22.0")]
+[assembly: AssemblyVersion("1.8.0.0")]
+[assembly: AssemblyFileVersion("1.8.0.0")]
diff --git a/Source/AutoHDR/Views/AutoHDRMainView.xaml b/Source/AutoHDR/Views/AutoHDRMainView.xaml
index ca0b456..46be28e 100644
--- a/Source/AutoHDR/Views/AutoHDRMainView.xaml
+++ b/Source/AutoHDR/Views/AutoHDRMainView.xaml
@@ -32,8 +32,9 @@
-
-
+
+
+
@@ -41,9 +42,7 @@
-
-
-
+
@@ -92,7 +91,7 @@
-
+
@@ -146,7 +145,7 @@
-
+
@@ -157,9 +156,10 @@
-
-
+
+
+
diff --git a/Source/AutoHDR/Views/DisplayActionView.xaml b/Source/AutoHDR/Views/DisplayActionView.xaml
index e05ed53..c6721a1 100644
--- a/Source/AutoHDR/Views/DisplayActionView.xaml
+++ b/Source/AutoHDR/Views/DisplayActionView.xaml
@@ -34,14 +34,14 @@
-
+
-
+
@@ -58,6 +58,13 @@
-
+
+
+
+
+
+
+
diff --git a/Source/AutoHDR/Views/ProfileManagerView.xaml b/Source/AutoHDR/Views/ProfileManagerView.xaml
index 89eb4f2..cff0411 100644
--- a/Source/AutoHDR/Views/ProfileManagerView.xaml
+++ b/Source/AutoHDR/Views/ProfileManagerView.xaml
@@ -50,8 +50,8 @@
-
-
+
+
@@ -149,7 +149,7 @@
-
+
diff --git a/Source/AutoHDR.ProjectResources/ProjectLocales.Designer.cs b/Source/AutoHDR.ProjectResources/ProjectLocales.Designer.cs
index e0a4804..cc7e9b1 100644
--- a/Source/AutoHDR.ProjectResources/ProjectLocales.Designer.cs
+++ b/Source/AutoHDR.ProjectResources/ProjectLocales.Designer.cs
@@ -638,11 +638,11 @@ public static string IsPrimaryMonitor {
}
///
/// Sucht eine lokalisierte Zeichenfolge, die Last action ähnelt.
///
- public static string LastAction {
+ public static string LastActions {
get {
- return ResourceManager.GetString("LastAction", resourceCulture);
+ return ResourceManager.GetString("LastActions", resourceCulture);
}
}
@@ -638,11 +638,11 @@ public static string IsPrimaryMonitor {
}
///
- /// Sucht eine lokalisierte Zeichenfolge, die Last action ähnelt.
+ /// Sucht eine lokalisierte Zeichenfolge, die Last actions ähnelt.
///
diff --git a/Source/Externals/CodectoryCore.UI.Wpf.dll b/Source/Externals/CodectoryCore.UI.Wpf.dll
index 7c9bdf6..1e160c4 100644
Binary files a/Source/Externals/CodectoryCore.UI.Wpf.dll and b/Source/Externals/CodectoryCore.UI.Wpf.dll differ